Index: /trunk/src/VBox/HostDrivers/VBoxPci/VBoxPci.c
===================================================================
--- /trunk/src/VBox/HostDrivers/VBoxPci/VBoxPci.c	(revision 65116)
+++ /trunk/src/VBox/HostDrivers/VBoxPci/VBoxPci.c	(revision 65117)
@@ -278,12 +278,12 @@
                                              uint64_t       u64RegionSize,
                                              int32_t        fFlags,
-                                             RTR0PTR        *pRegionBase)
-{
-    PVBOXRAWPCIINS pThis = DEVPORT_2_VBOXRAWPCIINS(pPort);
-    int            rc;
-
-    vboxPciDevLock(pThis);
-
-    rc = vboxPciOsDevMapRegion(pThis, iRegion, RegionStart, u64RegionSize, fFlags, pRegionBase);
+                                             RTR0PTR        *pRegionBaseR0)
+{
+    PVBOXRAWPCIINS pThis = DEVPORT_2_VBOXRAWPCIINS(pPort);
+    int            rc;
+
+    vboxPciDevLock(pThis);
+
+    rc = vboxPciOsDevMapRegion(pThis, iRegion, RegionStart, u64RegionSize, fFlags, pRegionBaseR0);
 
     vboxPciDevUnlock(pThis);
@@ -444,6 +444,9 @@
  * @returns VBox status code.
  * @param   pGlobals            The globals.
- * @param   pszName             The instance name.
+ * @param   u32HostAddress      Host address.
+ * @param   fFlags              Flags.
+ * @param   pVmCtx              VM context.
  * @param   ppDevPort           Where to store the pointer to our port interface.
+ * @param   pfDevFlags          The device flags.
  */
 static int vboxPciNewInstance(PVBOXRAWPCIGLOBALS pGlobals,
@@ -600,9 +603,9 @@
 static DECLCALLBACK(void)  vboxPciFactoryDeinitVm(PRAWPCIFACTORY       pFactory,
                                                   PVM                  pVM,
-                                                  PRAWPCIPERVM         pPciData)
-{
-    if (pPciData->pDriverData)
-    {
-        PVBOXRAWPCIDRVVM pThis = (PVBOXRAWPCIDRVVM)pPciData->pDriverData;
+                                                  PRAWPCIPERVM         pVmData)
+{
+    if (pVmData->pDriverData)
+    {
+        PVBOXRAWPCIDRVVM pThis = (PVBOXRAWPCIDRVVM)pVmData->pDriverData;
 
 #ifdef VBOX_WITH_IOMMU
@@ -619,5 +622,5 @@
 
         RTMemFree(pThis);
-        pPciData->pDriverData = NULL;
+        pVmData->pDriverData = NULL;
     }
 }

Index: /trunk/include/VBox/rawpci.h
===================================================================
--- /trunk/include/VBox/rawpci.h	(revision 65116)
+++ /trunk/include/VBox/rawpci.h	(revision 65117)
@@ -390,4 +390,9 @@
      *
      * @param   pPort     Pointer to this structure.
+     * @param   iRegion   Region number.
+     * @param   pRegionStart    Where to start the region address.
+     * @param   pu64RegionSize  Where to store the region size.
+     * @param   pfPresent   Where to store if the region is present.
+     * @param   pfFlags     Where to store the flags.
      */
     DECLR0CALLBACKMEMBER(int,  pfnGetRegionInfo,(PRAWPCIDEVPORT pPort,
@@ -403,4 +408,9 @@
      *
      * @param   pPort     Pointer to this structure.
+     * @param   iRegion   Region number.
+     * @param   RegionStart     Region start.
+     * @param   u64RegionSize   Region size.
+     * @param   fFlags    Flags.
+     * @param   pRegionBaseR0   Where to store the R0 address.
      */
     DECLR0CALLBACKMEMBER(int,  pfnMapRegion,(PRAWPCIDEVPORT pPort,
@@ -415,4 +425,8 @@
      *
      * @param   pPort     Pointer to this structure.
+     * @param   iRegion   Region number.
+     * @param   RegionStart     Region start.
+     * @param   u64RegionSize   Region size.
+     * @param   RegionBase      Base address.
      */
     DECLR0CALLBACKMEMBER(int,  pfnUnmapRegion,(PRAWPCIDEVPORT pPort,
@@ -496,5 +510,5 @@
      * release it once the pfnCreateAndConnect call(s) has been done.
      *
-     * @param   pIfFactory          Pointer to this structure.
+     * @param   pFactory            Pointer to this structure.
      */
     DECLR0CALLBACKMEMBER(void, pfnRelease,(PRAWPCIFACTORY pFactory));
@@ -507,5 +521,5 @@
      * @returns VBox status code.
      *
-     * @param   pIfFactory          Pointer to this structure.
+     * @param   pFactory            Pointer to this structure.
      * @param   u32HostAddress      Address of PCI device on the host.
      * @param   fFlags              Creation flags.
@@ -513,4 +527,5 @@
      * @param   ppDevPort           Where to store the pointer to the device port
      *                              on success.
+     * @param   pfDevFlags          Where to store the device flags.
      *
      */
@@ -528,11 +543,11 @@
      * @returns VBox status code.
      *
-     * @param   pIfFactory  Pointer to this structure.
+     * @param   pFactory    Pointer to this structure.
      * @param   pVM         The cross context VM structure.
      * @param   pPciData    Pointer to PCI data.
      */
     DECLR0CALLBACKMEMBER(int, pfnInitVm,(PRAWPCIFACTORY       pFactory,
                                          PVM                  pVM,
-                                         PRAWPCIPERVM         pPciData));
+                                         PRAWPCIPERVM         pVmData));
 
     /**
@@ -541,11 +556,11 @@
      * @returns VBox status code.
      *
-     * @param   pIfFactory  Pointer to this structure.
+     * @param   pFactory    Pointer to this structure.
      * @param   pVM         The cross context VM structure.
      * @param   pPciData    Pointer to PCI data.
      */
     DECLR0CALLBACKMEMBER(void, pfnDeinitVm,(PRAWPCIFACTORY       pFactory,
                                             PVM                  pVM,
-                                            PRAWPCIPERVM         pPciData));
+                                            PRAWPCIPERVM         pVmData));
 } RAWPCIFACTORY;
 
@@ -528,11 +543,11 @@
      * @param   pVM         The cross context VM structure.
-     * @param   pPciData    Pointer to PCI data.
+     * @param   pVmData     Pointer to PCI data.
      */
     DECLR0CALLBACKMEMBER(int, pfnInitVm,(PRAWPCIFACTORY       pFactory,
@@ -541,11 +556,11 @@
      * @param   pVM         The cross context VM structure.
-     * @param   pPciData    Pointer to PCI data.
+     * @param   pVmData     Pointer to PCI data.
      */
     DECLR0CALLBACKMEMBER(void, pfnDeinitVm,(PRAWPCIFACTORY       pFactory,